#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ResourceTypeDescriptorProperty :
	def __init__( self):
		self.id = None
		self.label = None
		self.type = None
		pass

class __ResourceTypeDescriptorPropertySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ResourceTypeDescriptorProperty()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		idValue = value['id']
		instance.id = serder.STRING.parse(idValue)
		labelValue = value['label']
		instance.label = serder.STRING.parse(labelValue)
		from netbluemind.resource.api.type.ResourceTypeDescriptorPropertyType import ResourceTypeDescriptorPropertyType
		from netbluemind.resource.api.type.ResourceTypeDescriptorPropertyType import __ResourceTypeDescriptorPropertyTypeSerDer__
		typeValue = value['type']
		instance.type = __ResourceTypeDescriptorPropertyTypeSerDer__().parse(typeValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		idValue = value.id
		instance["id"] = serder.STRING.encode(idValue)
		labelValue = value.label
		instance["label"] = serder.STRING.encode(labelValue)
		from netbluemind.resource.api.type.ResourceTypeDescriptorPropertyType import ResourceTypeDescriptorPropertyType
		from netbluemind.resource.api.type.ResourceTypeDescriptorPropertyType import __ResourceTypeDescriptorPropertyTypeSerDer__
		typeValue = value.type
		instance["type"] = __ResourceTypeDescriptorPropertyTypeSerDer__().encode(typeValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Folder :
	def __init__( self):
		self.uid = None
		self.id = None
		self.owner = None
		self.parentId = None
		self.name = None
		self.type = None
		self.contentUri = None
		self.path = None
		pass

class __FolderSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Folder()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		uidValue = value['uid']
		instance.uid = serder.LONG.parse(uidValue)
		idValue = value['id']
		instance.id = serder.LONG.parse(idValue)
		ownerValue = value['owner']
		instance.owner = serder.STRING.parse(ownerValue)
		parentIdValue = value['parentId']
		instance.parentId = serder.LONG.parse(parentIdValue)
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		from netbluemind.folder.api.FolderType import FolderType
		from netbluemind.folder.api.FolderType import __FolderTypeSerDer__
		typeValue = value['type']
		instance.type = __FolderTypeSerDer__().parse(typeValue)
		contentUriValue = value['contentUri']
		instance.contentUri = serder.STRING.parse(contentUriValue)
		pathValue = value['path']
		instance.path = serder.STRING.parse(pathValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		uidValue = value.uid
		instance["uid"] = serder.LONG.encode(uidValue)
		idValue = value.id
		instance["id"] = serder.LONG.encode(idValue)
		ownerValue = value.owner
		instance["owner"] = serder.STRING.encode(ownerValue)
		parentIdValue = value.parentId
		instance["parentId"] = serder.LONG.encode(parentIdValue)
		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		from netbluemind.folder.api.FolderType import FolderType
		from netbluemind.folder.api.FolderType import __FolderTypeSerDer__
		typeValue = value.type
		instance["type"] = __FolderTypeSerDer__().encode(typeValue)
		contentUriValue = value.contentUri
		instance["contentUri"] = serder.STRING.encode(contentUriValue)
		pathValue = value.path
		instance["path"] = serder.STRING.encode(pathValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardExplanatory :
	def __init__( self):
		self.urls = None
		self.categories = None
		self.note = None
		pass

class __VCardExplanatorySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardExplanatory()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.addressbook.api.VCardExplanatoryUrl import VCardExplanatoryUrl
		from netbluemind.addressbook.api.VCardExplanatoryUrl import __VCardExplanatoryUrlSerDer__
		urlsValue = value['urls']
		instance.urls = serder.ListSerDer(__VCardExplanatoryUrlSerDer__()).parse(urlsValue)
		from netbluemind.tag.api.TagRef import TagRef
		from netbluemind.tag.api.TagRef import __TagRefSerDer__
		categoriesValue = value['categories']
		instance.categories = serder.ListSerDer(__TagRefSerDer__()).parse(categoriesValue)
		noteValue = value['note']
		instance.note = serder.STRING.parse(noteValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.addressbook.api.VCardExplanatoryUrl import VCardExplanatoryUrl
		from netbluemind.addressbook.api.VCardExplanatoryUrl import __VCardExplanatoryUrlSerDer__
		urlsValue = value.urls
		instance["urls"] = serder.ListSerDer(__VCardExplanatoryUrlSerDer__()).encode(urlsValue)
		from netbluemind.tag.api.TagRef import TagRef
		from netbluemind.tag.api.TagRef import __TagRefSerDer__
		categoriesValue = value.categories
		instance["categories"] = serder.ListSerDer(__TagRefSerDer__()).encode(categoriesValue)
		noteValue = value.note
		instance["note"] = serder.STRING.encode(noteValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardIdentification :
	def __init__( self):
		self.formatedName = None
		self.name = None
		self.nickname = None
		self.photo = None
		self.birthday = None
		self.anniversary = None
		self.gender = None
		pass

class __VCardIdentificationSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardIdentification()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.addressbook.api.VCardIdentificationFormatedName import VCardIdentificationFormatedName
		from netbluemind.addressbook.api.VCardIdentificationFormatedName import __VCardIdentificationFormatedNameSerDer__
		formatedNameValue = value['formatedName']
		instance.formatedName = __VCardIdentificationFormatedNameSerDer__().parse(formatedNameValue)
		from netbluemind.addressbook.api.VCardIdentificationName import VCardIdentificationName
		from netbluemind.addressbook.api.VCardIdentificationName import __VCardIdentificationNameSerDer__
		nameValue = value['name']
		instance.name = __VCardIdentificationNameSerDer__().parse(nameValue)
		from netbluemind.addressbook.api.VCardIdentificationNickname import VCardIdentificationNickname
		from netbluemind.addressbook.api.VCardIdentificationNickname import __VCardIdentificationNicknameSerDer__
		nicknameValue = value['nickname']
		instance.nickname = __VCardIdentificationNicknameSerDer__().parse(nicknameValue)
		photoValue = value['photo']
		instance.photo = serder.BOOLEAN.parse(photoValue)
		birthdayValue = value['birthday']
		instance.birthday = serder.DATE.parse(birthdayValue)
		anniversaryValue = value['anniversary']
		instance.anniversary = serder.DATE.parse(anniversaryValue)
		from netbluemind.addressbook.api.VCardIdentificationGender import VCardIdentificationGender
		from netbluemind.addressbook.api.VCardIdentificationGender import __VCardIdentificationGenderSerDer__
		genderValue = value['gender']
		instance.gender = __VCardIdentificationGenderSerDer__().parse(genderValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.addressbook.api.VCardIdentificationFormatedName import VCardIdentificationFormatedName
		from netbluemind.addressbook.api.VCardIdentificationFormatedName import __VCardIdentificationFormatedNameSerDer__
		formatedNameValue = value.formatedName
		instance["formatedName"] = __VCardIdentificationFormatedNameSerDer__().encode(formatedNameValue)
		from netbluemind.addressbook.api.VCardIdentificationName import VCardIdentificationName
		from netbluemind.addressbook.api.VCardIdentificationName import __VCardIdentificationNameSerDer__
		nameValue = value.name
		instance["name"] = __VCardIdentificationNameSerDer__().encode(nameValue)
		from netbluemind.addressbook.api.VCardIdentificationNickname import VCardIdentificationNickname
		from netbluemind.addressbook.api.VCardIdentificationNickname import __VCardIdentificationNicknameSerDer__
		nicknameValue = value.nickname
		instance["nickname"] = __VCardIdentificationNicknameSerDer__().encode(nicknameValue)
		photoValue = value.photo
		instance["photo"] = serder.BOOLEAN.encode(photoValue)
		birthdayValue = value.birthday
		instance["birthday"] = serder.DATE.encode(birthdayValue)
		anniversaryValue = value.anniversary
		instance["anniversary"] = serder.DATE.encode(anniversaryValue)
		from netbluemind.addressbook.api.VCardIdentificationGender import VCardIdentificationGender
		from netbluemind.addressbook.api.VCardIdentificationGender import __VCardIdentificationGenderSerDer__
		genderValue = value.gender
		instance["gender"] = __VCardIdentificationGenderSerDer__().encode(genderValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class PrintOptions :
	def __init__( self):
		self.view = None
		self.format = None
		self.dateBegin = None
		self.dateEnd = None
		self.color = None
		self.showDetail = None
		self.layout = None
		self.calendars = None
		self.tagsFilter = None
		pass

class __PrintOptionsSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = PrintOptions()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.calendar.api.PrintOptionsPrintView import PrintOptionsPrintView
		from netbluemind.calendar.api.PrintOptionsPrintView import __PrintOptionsPrintViewSerDer__
		viewValue = value['view']
		instance.view = __PrintOptionsPrintViewSerDer__().parse(viewValue)
		from netbluemind.calendar.api.PrintOptionsPrintFormat import PrintOptionsPrintFormat
		from netbluemind.calendar.api.PrintOptionsPrintFormat import __PrintOptionsPrintFormatSerDer__
		formatValue = value['format']
		instance.format = __PrintOptionsPrintFormatSerDer__().parse(formatValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateBeginValue = value['dateBegin']
		instance.dateBegin = __BmDateTimeSerDer__().parse(dateBeginValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateEndValue = value['dateEnd']
		instance.dateEnd = __BmDateTimeSerDer__().parse(dateEndValue)
		colorValue = value['color']
		instance.color = serder.BOOLEAN.parse(colorValue)
		showDetailValue = value['showDetail']
		instance.showDetail = serder.BOOLEAN.parse(showDetailValue)
		from netbluemind.calendar.api.PrintOptionsPrintLayout import PrintOptionsPrintLayout
		from netbluemind.calendar.api.PrintOptionsPrintLayout import __PrintOptionsPrintLayoutSerDer__
		layoutValue = value['layout']
		instance.layout = __PrintOptionsPrintLayoutSerDer__().parse(layoutValue)
		from netbluemind.calendar.api.PrintOptionsCalendarMetadata import PrintOptionsCalendarMetadata
		from netbluemind.calendar.api.PrintOptionsCalendarMetadata import __PrintOptionsCalendarMetadataSerDer__
		calendarsValue = value['calendars']
		instance.calendars = serder.ListSerDer(__PrintOptionsCalendarMetadataSerDer__()).parse(calendarsValue)
		tagsFilterValue = value['tagsFilter']
		instance.tagsFilter = serder.SetSerDer(serder.STRING).parse(tagsFilterValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.calendar.api.PrintOptionsPrintView import PrintOptionsPrintView
		from netbluemind.calendar.api.PrintOptionsPrintView import __PrintOptionsPrintViewSerDer__
		viewValue = value.view
		instance["view"] = __PrintOptionsPrintViewSerDer__().encode(viewValue)
		from netbluemind.calendar.api.PrintOptionsPrintFormat import PrintOptionsPrintFormat
		from netbluemind.calendar.api.PrintOptionsPrintFormat import __PrintOptionsPrintFormatSerDer__
		formatValue = value.format
		instance["format"] = __PrintOptionsPrintFormatSerDer__().encode(formatValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateBeginValue = value.dateBegin
		instance["dateBegin"] = __BmDateTimeSerDer__().encode(dateBeginValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateEndValue = value.dateEnd
		instance["dateEnd"] = __BmDateTimeSerDer__().encode(dateEndValue)
		colorValue = value.color
		instance["color"] = serder.BOOLEAN.encode(colorValue)
		showDetailValue = value.showDetail
		instance["showDetail"] = serder.BOOLEAN.encode(showDetailValue)
		from netbluemind.calendar.api.PrintOptionsPrintLayout import PrintOptionsPrintLayout
		from netbluemind.calendar.api.PrintOptionsPrintLayout import __PrintOptionsPrintLayoutSerDer__
		layoutValue = value.layout
		instance["layout"] = __PrintOptionsPrintLayoutSerDer__().encode(layoutValue)
		from netbluemind.calendar.api.PrintOptionsCalendarMetadata import PrintOptionsCalendarMetadata
		from netbluemind.calendar.api.PrintOptionsCalendarMetadata import __PrintOptionsCalendarMetadataSerDer__
		calendarsValue = value.calendars
		instance["calendars"] = serder.ListSerDer(__PrintOptionsCalendarMetadataSerDer__()).encode(calendarsValue)
		tagsFilterValue = value.tagsFilter
		instance["tagsFilter"] = serder.SetSerDer(serder.STRING).encode(tagsFilterValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
class Group (DirBaseValue):
	def __init__( self):
		DirBaseValue.__init__(self)
		self.name = None
		self.description = None
		self.properties = None
		self.hiddenMembers = None
		self.mailArchived = None
		self.memberCount = None
		pass

class __GroupSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Group()
		__DirBaseValueSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		propertiesValue = value['properties']
		instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
		hiddenMembersValue = value['hiddenMembers']
		instance.hiddenMembers = serder.BOOLEAN.parse(hiddenMembersValue)
		mailArchivedValue = value['mailArchived']
		instance.mailArchived = serder.BOOLEAN.parse(mailArchivedValue)
		memberCountValue = value['memberCount']
		instance.memberCount = serder.INT.parse(memberCountValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__DirBaseValueSerDer__().encodeInternal(value,instance)

		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		propertiesValue = value.properties
		instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
		hiddenMembersValue = value.hiddenMembers
		instance["hiddenMembers"] = serder.BOOLEAN.encode(hiddenMembersValue)
		mailArchivedValue = value.mailArchived
		instance["mailArchived"] = serder.BOOLEAN.encode(mailArchivedValue)
		memberCountValue = value.memberCount
		instance["memberCount"] = serder.INT.encode(memberCountValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IVFreebusy_VERSION = "3.1.28078"

class IVFreebusy(BaseEndpoint):
	def __init__(self, apiKey, url ,containerUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/calendars/vfreebusy/{containerUid}'
		self.containerUid_ = containerUid
		self.base = self.base.replace('{containerUid}',containerUid)

	def get (self, query ):
		postUri = "";
		__data__ = None
		from netbluemind.calendar.api.VFreebusyQuery import VFreebusyQuery
		from netbluemind.calendar.api.VFreebusyQuery import __VFreebusyQuerySerDer__
		__data__ = __VFreebusyQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IVFreebusy_VERSION}, data = json.dumps(__data__));
		from netbluemind.calendar.api.VFreebusy import VFreebusy
		from netbluemind.calendar.api.VFreebusy import __VFreebusySerDer__
		return self.handleResult__(__VFreebusySerDer__(), response)
	def getAsString (self, query ):
		postUri = "/_ics";
		__data__ = None
		from netbluemind.calendar.api.VFreebusyQuery import VFreebusyQuery
		from netbluemind.calendar.api.VFreebusyQuery import __VFreebusyQuerySerDer__
		__data__ = __VFreebusyQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IVFreebusy_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.STRING, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VFreebusy :
	def __init__( self):
		self.dtstart = None
		self.dtend = None
		self.slots = None
		pass

class __VFreebusySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VFreebusy()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtstartValue = value['dtstart']
		instance.dtstart = __BmDateTimeSerDer__().parse(dtstartValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtendValue = value['dtend']
		instance.dtend = __BmDateTimeSerDer__().parse(dtendValue)
		from netbluemind.calendar.api.VFreebusySlot import VFreebusySlot
		from netbluemind.calendar.api.VFreebusySlot import __VFreebusySlotSerDer__
		slotsValue = value['slots']
		instance.slots = serder.ListSerDer(__VFreebusySlotSerDer__()).parse(slotsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtstartValue = value.dtstart
		instance["dtstart"] = __BmDateTimeSerDer__().encode(dtstartValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtendValue = value.dtend
		instance["dtend"] = __BmDateTimeSerDer__().encode(dtendValue)
		from netbluemind.calendar.api.VFreebusySlot import VFreebusySlot
		from netbluemind.calendar.api.VFreebusySlot import __VFreebusySlotSerDer__
		slotsValue = value.slots
		instance["slots"] = serder.ListSerDer(__VFreebusySlotSerDer__()).encode(slotsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class TaskStatus :
	def __init__( self):
		self.steps = None
		self.progress = None
		self.lastLogEntry = None
		self.state = None
		self.result = None
		pass

class __TaskStatusSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = TaskStatus()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		stepsValue = value['steps']
		instance.steps = serder.DOUBLE.parse(stepsValue)
		progressValue = value['progress']
		instance.progress = serder.DOUBLE.parse(progressValue)
		lastLogEntryValue = value['lastLogEntry']
		instance.lastLogEntry = serder.STRING.parse(lastLogEntryValue)
		from netbluemind.core.task.api.TaskStatusState import TaskStatusState
		from netbluemind.core.task.api.TaskStatusState import __TaskStatusStateSerDer__
		stateValue = value['state']
		instance.state = __TaskStatusStateSerDer__().parse(stateValue)
		resultValue = value['result']
		instance.result = serder.STRING.parse(resultValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		stepsValue = value.steps
		instance["steps"] = serder.DOUBLE.encode(stepsValue)
		progressValue = value.progress
		instance["progress"] = serder.DOUBLE.encode(progressValue)
		lastLogEntryValue = value.lastLogEntry
		instance["lastLogEntry"] = serder.STRING.encode(lastLogEntryValue)
		from netbluemind.core.task.api.TaskStatusState import TaskStatusState
		from netbluemind.core.task.api.TaskStatusState import __TaskStatusStateSerDer__
		stateValue = value.state
		instance["state"] = __TaskStatusStateSerDer__().encode(stateValue)
		resultValue = value.result
		instance["result"] = serder.STRING.encode(resultValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class JobExecution :
	def __init__( self):
		self.startDate = None
		self.endDate = None
		self.domainName = None
		self.status = None
		self.jobId = None
		self.execGroup = None
		self.id = None
		pass

class __JobExecutionSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = JobExecution()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		startDateValue = value['startDate']
		instance.startDate = serder.DATE.parse(startDateValue)
		endDateValue = value['endDate']
		instance.endDate = serder.DATE.parse(endDateValue)
		domainNameValue = value['domainName']
		instance.domainName = serder.STRING.parse(domainNameValue)
		from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
		from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
		statusValue = value['status']
		instance.status = __JobExitStatusSerDer__().parse(statusValue)
		jobIdValue = value['jobId']
		instance.jobId = serder.STRING.parse(jobIdValue)
		execGroupValue = value['execGroup']
		instance.execGroup = serder.STRING.parse(execGroupValue)
		idValue = value['id']
		instance.id = serder.INT.parse(idValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		startDateValue = value.startDate
		instance["startDate"] = serder.DATE.encode(startDateValue)
		endDateValue = value.endDate
		instance["endDate"] = serder.DATE.encode(endDateValue)
		domainNameValue = value.domainName
		instance["domainName"] = serder.STRING.encode(domainNameValue)
		from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
		from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
		statusValue = value.status
		instance["status"] = __JobExitStatusSerDer__().encode(statusValue)
		jobIdValue = value.jobId
		instance["jobId"] = serder.STRING.encode(jobIdValue)
		execGroupValue = value.execGroup
		instance["execGroup"] = serder.STRING.encode(execGroupValue)
		idValue = value.id
		instance["id"] = serder.INT.encode(idValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ContainerSyncResult :
	def __init__( self):
		self.status = None
		self.added = None
		self.updated = None
		self.removed = None
		pass

class __ContainerSyncResultSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ContainerSyncResult()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.core.container.model.ContainerSyncStatus import ContainerSyncStatus
		from netbluemind.core.container.model.ContainerSyncStatus import __ContainerSyncStatusSerDer__
		statusValue = value['status']
		instance.status = __ContainerSyncStatusSerDer__().parse(statusValue)
		addedValue = value['added']
		instance.added = serder.INT.parse(addedValue)
		updatedValue = value['updated']
		instance.updated = serder.INT.parse(updatedValue)
		removedValue = value['removed']
		instance.removed = serder.INT.parse(removedValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.core.container.model.ContainerSyncStatus import ContainerSyncStatus
		from netbluemind.core.container.model.ContainerSyncStatus import __ContainerSyncStatusSerDer__
		statusValue = value.status
		instance["status"] = __ContainerSyncStatusSerDer__().encode(statusValue)
		addedValue = value.added
		instance["added"] = serder.INT.encode(addedValue)
		updatedValue = value.updated
		instance["updated"] = serder.INT.encode(updatedValue)
		removedValue = value.removed
		instance["removed"] = serder.INT.encode(removedValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DomainTemplateTag :
	def __init__( self):
		self.value = None
		self.description = None
		self.multival = None
		self.mandatory = None
		self.autoAssign = None
		pass

class __DomainTemplateTagSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = DomainTemplateTag()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		valueValue = value['value']
		instance.value = serder.STRING.parse(valueValue)
		from netbluemind.system.api.DomainTemplateDescription import DomainTemplateDescription
		from netbluemind.system.api.DomainTemplateDescription import __DomainTemplateDescriptionSerDer__
		descriptionValue = value['description']
		instance.description = __DomainTemplateDescriptionSerDer__().parse(descriptionValue)
		multivalValue = value['multival']
		instance.multival = serder.BOOLEAN.parse(multivalValue)
		mandatoryValue = value['mandatory']
		instance.mandatory = serder.BOOLEAN.parse(mandatoryValue)
		autoAssignValue = value['autoAssign']
		instance.autoAssign = serder.BOOLEAN.parse(autoAssignValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		valueValue = value.value
		instance["value"] = serder.STRING.encode(valueValue)
		from netbluemind.system.api.DomainTemplateDescription import DomainTemplateDescription
		from netbluemind.system.api.DomainTemplateDescription import __DomainTemplateDescriptionSerDer__
		descriptionValue = value.description
		instance["description"] = __DomainTemplateDescriptionSerDer__().encode(descriptionValue)
		multivalValue = value.multival
		instance["multival"] = serder.BOOLEAN.encode(multivalValue)
		mandatoryValue = value.mandatory
		instance["mandatory"] = serder.BOOLEAN.encode(mandatoryValue)
		autoAssignValue = value.autoAssign
		instance["autoAssign"] = serder.BOOLEAN.encode(autoAssignValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IResources_VERSION = "3.1.28078"

class IResources(BaseEndpoint):
	def __init__(self, apiKey, url ,domainUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/resources/{domainUid}'
		self.domainUid_ = domainUid
		self.base = self.base.replace('{domainUid}',domainUid)

	def update (self, uid , rd ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.resource.api.ResourceDescriptor import ResourceDescriptor
		from netbluemind.resource.api.ResourceDescriptor import __ResourceDescriptorSerDer__
		__data__ = __ResourceDescriptorSerDer__().encode(rd)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getIcon (self, uid ):
		postUri = "/{uid}/icon";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def setIcon (self, uid , icon ):
		postUri = "/{uid}/icon";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.ByteArraySerDer.encode(icon)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def get (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		from netbluemind.resource.api.ResourceDescriptor import ResourceDescriptor
		from netbluemind.resource.api.ResourceDescriptor import __ResourceDescriptorSerDer__
		return self.handleResult__(__ResourceDescriptorSerDer__(), response)
	def byEmail (self, email ):
		postUri = "/byEmail/{email}";
		__data__ = None
		postUri = postUri.replace("{email}",email);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		from netbluemind.resource.api.ResourceDescriptor import ResourceDescriptor
		from netbluemind.resource.api.ResourceDescriptor import __ResourceDescriptorSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__ResourceDescriptorSerDer__()), response)
	def create (self, uid , rd ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.resource.api.ResourceDescriptor import ResourceDescriptor
		from netbluemind.resource.api.ResourceDescriptor import __ResourceDescriptorSerDer__
		__data__ = __ResourceDescriptorSerDer__().encode(rd)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def byType (self, type ):
		postUri = "/byType/{type}";
		__data__ = None
		postUri = postUri.replace("{type}",type);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class IdentityDescription :
	def __init__( self):
		self.mbox = None
		self.id = None
		self.email = None
		self.name = None
		self.isDefault = None
		self.displayname = None
		pass

class __IdentityDescriptionSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = IdentityDescription()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		mboxValue = value['mbox']
		instance.mbox = serder.STRING.parse(mboxValue)
		idValue = value['id']
		instance.id = serder.STRING.parse(idValue)
		emailValue = value['email']
		instance.email = serder.STRING.parse(emailValue)
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		isDefaultValue = value['isDefault']
		instance.isDefault = serder.BOOLEAN.parse(isDefaultValue)
		displaynameValue = value['displayname']
		instance.displayname = serder.STRING.parse(displaynameValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		mboxValue = value.mbox
		instance["mbox"] = serder.STRING.encode(mboxValue)
		idValue = value.id
		instance["id"] = serder.STRING.encode(idValue)
		emailValue = value.email
		instance["email"] = serder.STRING.encode(emailValue)
		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		isDefaultValue = value.isDefault
		instance["isDefault"] = serder.BOOLEAN.encode(isDefaultValue)
		displaynameValue = value.displayname
		instance["displayname"] = serder.STRING.encode(displaynameValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class InstallationVersion :
	def __init__( self):
		self.databaseVersion = None
		self.softwareVersion = None
		self.versionName = None
		self.needsUpgrade = None
		pass

class __InstallationVersionSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = InstallationVersion()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		databaseVersionValue = value['databaseVersion']
		instance.databaseVersion = serder.STRING.parse(databaseVersionValue)
		softwareVersionValue = value['softwareVersion']
		instance.softwareVersion = serder.STRING.parse(softwareVersionValue)
		versionNameValue = value['versionName']
		instance.versionName = serder.STRING.parse(versionNameValue)
		needsUpgradeValue = value['needsUpgrade']
		instance.needsUpgrade = serder.BOOLEAN.parse(needsUpgradeValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		databaseVersionValue = value.databaseVersion
		instance["databaseVersion"] = serder.STRING.encode(databaseVersionValue)
		softwareVersionValue = value.softwareVersion
		instance["softwareVersion"] = serder.STRING.encode(softwareVersionValue)
		versionNameValue = value.versionName
		instance["versionName"] = serder.STRING.encode(versionNameValue)
		needsUpgradeValue = value.needsUpgrade
		instance["needsUpgrade"] = serder.BOOLEAN.encode(needsUpgradeValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class AddressBookDescriptor :
	def __init__( self):
		self.name = None
		self.domainUid = None
		self.owner = None
		self.system = None
		self.settings = None
		self.orgUnitUid = None
		pass

class __AddressBookDescriptorSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = AddressBookDescriptor()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		domainUidValue = value['domainUid']
		instance.domainUid = serder.STRING.parse(domainUidValue)
		ownerValue = value['owner']
		instance.owner = serder.STRING.parse(ownerValue)
		systemValue = value['system']
		instance.system = serder.BOOLEAN.parse(systemValue)
		settingsValue = value['settings']
		instance.settings = serder.MapSerDer(serder.STRING).parse(settingsValue)
		orgUnitUidValue = value['orgUnitUid']
		instance.orgUnitUid = serder.STRING.parse(orgUnitUidValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		domainUidValue = value.domainUid
		instance["domainUid"] = serder.STRING.encode(domainUidValue)
		ownerValue = value.owner
		instance["owner"] = serder.STRING.encode(ownerValue)
		systemValue = value.system
		instance["system"] = serder.BOOLEAN.encode(systemValue)
		settingsValue = value.settings
		instance["settings"] = serder.MapSerDer(serder.STRING).encode(settingsValue)
		orgUnitUidValue = value.orgUnitUid
		instance["orgUnitUid"] = serder.STRING.encode(orgUnitUidValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class GenerationContent :
	def __init__( self):
		self.generationId = None
		self.domains = None
		self.servers = None
		self.entries = None
		self.capabilities = None
		pass

class __GenerationContentSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = GenerationContent()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		generationIdValue = value['generationId']
		instance.generationId = serder.INT.parse(generationIdValue)
		from netbluemind.domain.api.Domain import Domain
		from netbluemind.domain.api.Domain import __DomainSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		domainsValue = value['domains']
		instance.domains = serder.ListSerDer(__ItemValueSerDer__(__DomainSerDer__())).parse(domainsValue)
		from netbluemind.server.api.Server import Server
		from netbluemind.server.api.Server import __ServerSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		serversValue = value['servers']
		instance.servers = serder.ListSerDer(__ItemValueSerDer__(__ServerSerDer__())).parse(serversValue)
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		entriesValue = value['entries']
		instance.entries = serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())).parse(entriesValue)
		from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
		from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
		capabilitiesValue = value['capabilities']
		instance.capabilities = serder.ListSerDer(__RestoreOperationSerDer__()).parse(capabilitiesValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		generationIdValue = value.generationId
		instance["generationId"] = serder.INT.encode(generationIdValue)
		from netbluemind.domain.api.Domain import Domain
		from netbluemind.domain.api.Domain import __DomainSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		domainsValue = value.domains
		instance["domains"] = serder.ListSerDer(__ItemValueSerDer__(__DomainSerDer__())).encode(domainsValue)
		from netbluemind.server.api.Server import Server
		from netbluemind.server.api.Server import __ServerSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		serversValue = value.servers
		instance["servers"] = serder.ListSerDer(__ItemValueSerDer__(__ServerSerDer__())).encode(serversValue)
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		entriesValue = value.entries
		instance["entries"] = serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())).encode(entriesValue)
		from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
		from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
		capabilitiesValue = value.capabilities
		instance["capabilities"] = serder.ListSerDer(__RestoreOperationSerDer__()).encode(capabilitiesValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DirEntryQuery :
	def __init__( self):
		self.order = None
		self.nameFilter = None
		self.hiddenFilter = None
		self.emailFilter = None
		self.nameOrEmailFilter = None
		self.stateFilter = None
		self.systemFilter = None
		self.kindsFilter = None
		self.entries = None
		self.from_ = None
		self.size = None
		self.entryUidFilter = None
		self.entriesFilterOut = None
		self.onlyManagable = None
		pass

class __DirEntryQuerySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = DirEntryQuery()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.directory.api.DirEntryQueryOrder import DirEntryQueryOrder
		from netbluemind.directory.api.DirEntryQueryOrder import __DirEntryQueryOrderSerDer__
		orderValue = value['order']
		instance.order = __DirEntryQueryOrderSerDer__().parse(orderValue)
		nameFilterValue = value['nameFilter']
		instance.nameFilter = serder.STRING.parse(nameFilterValue)
		hiddenFilterValue = value['hiddenFilter']
		instance.hiddenFilter = serder.BOOLEAN.parse(hiddenFilterValue)
		emailFilterValue = value['emailFilter']
		instance.emailFilter = serder.STRING.parse(emailFilterValue)
		nameOrEmailFilterValue = value['nameOrEmailFilter']
		instance.nameOrEmailFilter = serder.STRING.parse(nameOrEmailFilterValue)
		from netbluemind.directory.api.DirEntryQueryStateFilter import DirEntryQueryStateFilter
		from netbluemind.directory.api.DirEntryQueryStateFilter import __DirEntryQueryStateFilterSerDer__
		stateFilterValue = value['stateFilter']
		instance.stateFilter = __DirEntryQueryStateFilterSerDer__().parse(stateFilterValue)
		systemFilterValue = value['systemFilter']
		instance.systemFilter = serder.BOOLEAN.parse(systemFilterValue)
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		kindsFilterValue = value['kindsFilter']
		instance.kindsFilter = serder.ListSerDer(__DirEntryKindSerDer__()).parse(kindsFilterValue)
		entriesValue = value['entries']
		instance.entries = serder.ListSerDer(serder.STRING).parse(entriesValue)
		from_Value = value['from']
		instance.from_ = serder.INT.parse(from_Value)
		sizeValue = value['size']
		instance.size = serder.INT.parse(sizeValue)
		entryUidFilterValue = value['entryUidFilter']
		instance.entryUidFilter = serder.ListSerDer(serder.STRING).parse(entryUidFilterValue)
		entriesFilterOutValue = value['entriesFilterOut']
		instance.entriesFilterOut = serder.ListSerDer(serder.STRING).parse(entriesFilterOutValue)
		onlyManagableValue = value['onlyManagable']
		instance.onlyManagable = serder.BOOLEAN.parse(onlyManagableValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.directory.api.DirEntryQueryOrder import DirEntryQueryOrder
		from netbluemind.directory.api.DirEntryQueryOrder import __DirEntryQueryOrderSerDer__
		orderValue = value.order
		instance["order"] = __DirEntryQueryOrderSerDer__().encode(orderValue)
		nameFilterValue = value.nameFilter
		instance["nameFilter"] = serder.STRING.encode(nameFilterValue)
		hiddenFilterValue = value.hiddenFilter
		instance["hiddenFilter"] = serder.BOOLEAN.encode(hiddenFilterValue)
		emailFilterValue = value.emailFilter
		instance["emailFilter"] = serder.STRING.encode(emailFilterValue)
		nameOrEmailFilterValue = value.nameOrEmailFilter
		instance["nameOrEmailFilter"] = serder.STRING.encode(nameOrEmailFilterValue)
		from netbluemind.directory.api.DirEntryQueryStateFilter import DirEntryQueryStateFilter
		from netbluemind.directory.api.DirEntryQueryStateFilter import __DirEntryQueryStateFilterSerDer__
		stateFilterValue = value.stateFilter
		instance["stateFilter"] = __DirEntryQueryStateFilterSerDer__().encode(stateFilterValue)
		systemFilterValue = value.systemFilter
		instance["systemFilter"] = serder.BOOLEAN.encode(systemFilterValue)
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		kindsFilterValue = value.kindsFilter
		instance["kindsFilter"] = serder.ListSerDer(__DirEntryKindSerDer__()).encode(kindsFilterValue)
		entriesValue = value.entries
		instance["entries"] = serder.ListSerDer(serder.STRING).encode(entriesValue)
		from_Value = value.from_
		instance["from"] = serder.INT.encode(from_Value)
		sizeValue = value.size
		instance["size"] = serder.INT.encode(sizeValue)
		entryUidFilterValue = value.entryUidFilter
		instance["entryUidFilter"] = serder.ListSerDer(serder.STRING).encode(entryUidFilterValue)
		entriesFilterOutValue = value.entriesFilterOut
		instance["entriesFilterOut"] = serder.ListSerDer(serder.STRING).encode(entriesFilterOutValue)
		onlyManagableValue = value.onlyManagable
		instance["onlyManagable"] = serder.BOOLEAN.encode(onlyManagableValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class RetentionPolicy :
	def __init__( self):
		self.daily = None
		self.weekly = None
		self.monthly = None
		pass

class __RetentionPolicySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = RetentionPolicy()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		dailyValue = value['daily']
		instance.daily = serder.INT.parse(dailyValue)
		weeklyValue = value['weekly']
		instance.weekly = serder.INT.parse(weeklyValue)
		monthlyValue = value['monthly']
		instance.monthly = serder.INT.parse(monthlyValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		dailyValue = value.daily
		instance["daily"] = serder.INT.encode(dailyValue)
		weeklyValue = value.weekly
		instance["weekly"] = serder.INT.encode(weeklyValue)
		monthlyValue = value.monthly
		instance["monthly"] = serder.INT.encode(monthlyValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class BaseContainerDescriptor :
	def __init__( self):
		self.uid = None
		self.name = None
		self.owner = None
		self.type = None
		self.defaultContainer = None
		self.readOnly = None
		self.domainUid = None
		self.ownerDisplayname = None
		self.ownerDirEntryPath = None
		self.settings = None
		pass

class __BaseContainerDescriptorSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = BaseContainerDescriptor()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		uidValue = value['uid']
		instance.uid = serder.STRING.parse(uidValue)
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		ownerValue = value['owner']
		instance.owner = serder.STRING.parse(ownerValue)
		typeValue = value['type']
		instance.type = serder.STRING.parse(typeValue)
		defaultContainerValue = value['defaultContainer']
		instance.defaultContainer = serder.BOOLEAN.parse(defaultContainerValue)
		readOnlyValue = value['readOnly']
		instance.readOnly = serder.BOOLEAN.parse(readOnlyValue)
		domainUidValue = value['domainUid']
		instance.domainUid = serder.STRING.parse(domainUidValue)
		ownerDisplaynameValue = value['ownerDisplayname']
		instance.ownerDisplayname = serder.STRING.parse(ownerDisplaynameValue)
		ownerDirEntryPathValue = value['ownerDirEntryPath']
		instance.ownerDirEntryPath = serder.STRING.parse(ownerDirEntryPathValue)
		settingsValue = value['settings']
		instance.settings = serder.MapSerDer(serder.STRING).parse(settingsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		uidValue = value.uid
		instance["uid"] = serder.STRING.encode(uidValue)
		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		ownerValue = value.owner
		instance["owner"] = serder.STRING.encode(ownerValue)
		typeValue = value.type
		instance["type"] = serder.STRING.encode(typeValue)
		defaultContainerValue = value.defaultContainer
		instance["defaultContainer"] = serder.BOOLEAN.encode(defaultContainerValue)
		readOnlyValue = value.readOnly
		instance["readOnly"] = serder.BOOLEAN.encode(readOnlyValue)
		domainUidValue = value.domainUid
		instance["domainUid"] = serder.STRING.encode(domainUidValue)
		ownerDisplaynameValue = value.ownerDisplayname
		instance["ownerDisplayname"] = serder.STRING.encode(ownerDisplaynameValue)
		ownerDirEntryPathValue = value.ownerDirEntryPath
		instance["ownerDirEntryPath"] = serder.STRING.encode(ownerDirEntryPathValue)
		settingsValue = value.settings
		instance["settings"] = serder.MapSerDer(serder.STRING).encode(settingsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class JobDomainStatus :
	def __init__( self):
		self.domain = None
		self.status = None
		pass

class __JobDomainStatusSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = JobDomainStatus()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		domainValue = value['domain']
		instance.domain = serder.STRING.parse(domainValue)
		from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
		from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
		statusValue = value['status']
		instance.status = __JobExitStatusSerDer__().parse(statusValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		domainValue = value.domain
		instance["domain"] = serder.STRING.encode(domainValue)
		from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
		from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
		statusValue = value.status
		instance["status"] = __JobExitStatusSerDer__().encode(statusValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class TodoListsVTodoQuery :
	def __init__( self):
		self.owner = None
		self.containers = None
		self.vtodoQuery = None
		pass

class __TodoListsVTodoQuerySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = TodoListsVTodoQuery()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		ownerValue = value['owner']
		instance.owner = serder.STRING.parse(ownerValue)
		containersValue = value['containers']
		instance.containers = serder.ListSerDer(serder.STRING).parse(containersValue)
		from netbluemind.todolist.api.VTodoQuery import VTodoQuery
		from netbluemind.todolist.api.VTodoQuery import __VTodoQuerySerDer__
		vtodoQueryValue = value['vtodoQuery']
		instance.vtodoQuery = __VTodoQuerySerDer__().parse(vtodoQueryValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		ownerValue = value.owner
		instance["owner"] = serder.STRING.encode(ownerValue)
		containersValue = value.containers
		instance["containers"] = serder.ListSerDer(serder.STRING).encode(containersValue)
		from netbluemind.todolist.api.VTodoQuery import VTodoQuery
		from netbluemind.todolist.api.VTodoQuery import __VTodoQuerySerDer__
		vtodoQueryValue = value.vtodoQuery
		instance["vtodoQuery"] = __VTodoQuerySerDer__().encode(vtodoQueryValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class SubscriptionInformations :
	def __init__( self):
		self.version = None
		self.installationVersion = None
		self.customer = None
		self.customerCode = None
		self.dealer = None
		self.distributor = None
		self.serverOs = None
		self.kind = None
		self.starts = None
		self.ends = None
		self.valid = None
		self.pubKeyFingerprint = None
		self.validProvider = None
		self.indicator = None
		self.contacts = None
		self.messages = None
		pass

class __SubscriptionInformationsSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = SubscriptionInformations()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		versionValue = value['version']
		instance.version = serder.STRING.parse(versionValue)
		installationVersionValue = value['installationVersion']
		instance.installationVersion = serder.STRING.parse(installationVersionValue)
		customerValue = value['customer']
		instance.customer = serder.STRING.parse(customerValue)
		customerCodeValue = value['customerCode']
		instance.customerCode = serder.STRING.parse(customerCodeValue)
		dealerValue = value['dealer']
		instance.dealer = serder.STRING.parse(dealerValue)
		distributorValue = value['distributor']
		instance.distributor = serder.STRING.parse(distributorValue)
		serverOsValue = value['serverOs']
		instance.serverOs = serder.STRING.parse(serverOsValue)
		from netbluemind.system.api.SubscriptionInformationsKind import SubscriptionInformationsKind
		from netbluemind.system.api.SubscriptionInformationsKind import __SubscriptionInformationsKindSerDer__
		kindValue = value['kind']
		instance.kind = __SubscriptionInformationsKindSerDer__().parse(kindValue)
		startsValue = value['starts']
		instance.starts = serder.DATE.parse(startsValue)
		endsValue = value['ends']
		instance.ends = serder.DATE.parse(endsValue)
		validValue = value['valid']
		instance.valid = serder.BOOLEAN.parse(validValue)
		pubKeyFingerprintValue = value['pubKeyFingerprint']
		instance.pubKeyFingerprint = serder.STRING.parse(pubKeyFingerprintValue)
		validProviderValue = value['validProvider']
		instance.validProvider = serder.BOOLEAN.parse(validProviderValue)
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import SubscriptionInformationsInstallationIndicator
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import __SubscriptionInformationsInstallationIndicatorSerDer__
		indicatorValue = value['indicator']
		instance.indicator = serder.ListSerDer(__SubscriptionInformationsInstallationIndicatorSerDer__()).parse(indicatorValue)
		contactsValue = value['contacts']
		instance.contacts = serder.ListSerDer(serder.STRING).parse(contactsValue)
		from netbluemind.system.api.SubscriptionInformationsMessage import SubscriptionInformationsMessage
		from netbluemind.system.api.SubscriptionInformationsMessage import __SubscriptionInformationsMessageSerDer__
		messagesValue = value['messages']
		instance.messages = serder.ListSerDer(__SubscriptionInformationsMessageSerDer__()).parse(messagesValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		versionValue = value.version
		instance["version"] = serder.STRING.encode(versionValue)
		installationVersionValue = value.installationVersion
		instance["installationVersion"] = serder.STRING.encode(installationVersionValue)
		customerValue = value.customer
		instance["customer"] = serder.STRING.encode(customerValue)
		customerCodeValue = value.customerCode
		instance["customerCode"] = serder.STRING.encode(customerCodeValue)
		dealerValue = value.dealer
		instance["dealer"] = serder.STRING.encode(dealerValue)
		distributorValue = value.distributor
		instance["distributor"] = serder.STRING.encode(distributorValue)
		serverOsValue = value.serverOs
		instance["serverOs"] = serder.STRING.encode(serverOsValue)
		from netbluemind.system.api.SubscriptionInformationsKind import SubscriptionInformationsKind
		from netbluemind.system.api.SubscriptionInformationsKind import __SubscriptionInformationsKindSerDer__
		kindValue = value.kind
		instance["kind"] = __SubscriptionInformationsKindSerDer__().encode(kindValue)
		startsValue = value.starts
		instance["starts"] = serder.DATE.encode(startsValue)
		endsValue = value.ends
		instance["ends"] = serder.DATE.encode(endsValue)
		validValue = value.valid
		instance["valid"] = serder.BOOLEAN.encode(validValue)
		pubKeyFingerprintValue = value.pubKeyFingerprint
		instance["pubKeyFingerprint"] = serder.STRING.encode(pubKeyFingerprintValue)
		validProviderValue = value.validProvider
		instance["validProvider"] = serder.BOOLEAN.encode(validProviderValue)
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import SubscriptionInformationsInstallationIndicator
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import __SubscriptionInformationsInstallationIndicatorSerDer__
		indicatorValue = value.indicator
		instance["indicator"] = serder.ListSerDer(__SubscriptionInformationsInstallationIndicatorSerDer__()).encode(indicatorValue)
		contactsValue = value.contacts
		instance["contacts"] = serder.ListSerDer(serder.STRING).encode(contactsValue)
		from netbluemind.system.api.SubscriptionInformationsMessage import SubscriptionInformationsMessage
		from netbluemind.system.api.SubscriptionInformationsMessage import __SubscriptionInformationsMessageSerDer__
		messagesValue = value.messages
		instance["messages"] = serder.ListSerDer(__SubscriptionInformationsMessageSerDer__()).encode(messagesValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ItemValue :
	def __init__( self):
		self.value = None
		self.uid = None
		self.internalId = None
		self.version = None
		self.displayName = None
		self.externalId = None
		self.createdBy = None
		self.updatedBy = None
		self.created = None
		self.updated = None
		pass

class __ItemValueSerDer__:
	def __init__( self  , T):
		self.paramSerDerT = T
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ItemValue()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		valueValue = value['value']
		instance.value = self.paramSerDerT.parse(valueValue)
		uidValue = value['uid']
		instance.uid = serder.STRING.parse(uidValue)
		internalIdValue = value['internalId']
		instance.internalId = serder.LONG.parse(internalIdValue)
		versionValue = value['version']
		instance.version = serder.LONG.parse(versionValue)
		displayNameValue = value['displayName']
		instance.displayName = serder.STRING.parse(displayNameValue)
		externalIdValue = value['externalId']
		instance.externalId = serder.STRING.parse(externalIdValue)
		createdByValue = value['createdBy']
		instance.createdBy = serder.STRING.parse(createdByValue)
		updatedByValue = value['updatedBy']
		instance.updatedBy = serder.STRING.parse(updatedByValue)
		createdValue = value['created']
		instance.created = serder.DATE.parse(createdValue)
		updatedValue = value['updated']
		instance.updated = serder.DATE.parse(updatedValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		valueValue = value.value
		instance["value"] = self.paramSerDerT.encode(valueValue)
		uidValue = value.uid
		instance["uid"] = serder.STRING.encode(uidValue)
		internalIdValue = value.internalId
		instance["internalId"] = serder.LONG.encode(internalIdValue)
		versionValue = value.version
		instance["version"] = serder.LONG.encode(versionValue)
		displayNameValue = value.displayName
		instance["displayName"] = serder.STRING.encode(displayNameValue)
		externalIdValue = value.externalId
		instance["externalId"] = serder.STRING.encode(externalIdValue)
		createdByValue = value.createdBy
		instance["createdBy"] = serder.STRING.encode(createdByValue)
		updatedByValue = value.updatedBy
		instance["updatedBy"] = serder.STRING.encode(updatedByValue)
		createdValue = value.created
		instance["created"] = serder.DATE.encode(createdValue)
		updatedValue = value.updated
		instance["updated"] = serder.DATE.encode(updatedValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.addressbook.api.VCardBasicAttribute import VCardBasicAttribute
from netbluemind.addressbook.api.VCardBasicAttribute import __VCardBasicAttributeSerDer__
class VCardIdentificationName (VCardBasicAttribute):
	def __init__( self):
		VCardBasicAttribute.__init__(self)
		self.familyNames = None
		self.givenNames = None
		self.additionalNames = None
		self.prefixes = None
		self.suffixes = None
		pass

class __VCardIdentificationNameSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardIdentificationName()
		__VCardBasicAttributeSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		familyNamesValue = value['familyNames']
		instance.familyNames = serder.STRING.parse(familyNamesValue)
		givenNamesValue = value['givenNames']
		instance.givenNames = serder.STRING.parse(givenNamesValue)
		additionalNamesValue = value['additionalNames']
		instance.additionalNames = serder.STRING.parse(additionalNamesValue)
		prefixesValue = value['prefixes']
		instance.prefixes = serder.STRING.parse(prefixesValue)
		suffixesValue = value['suffixes']
		instance.suffixes = serder.STRING.parse(suffixesValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__VCardBasicAttributeSerDer__().encodeInternal(value,instance)

		familyNamesValue = value.familyNames
		instance["familyNames"] = serder.STRING.encode(familyNamesValue)
		givenNamesValue = value.givenNames
		instance["givenNames"] = serder.STRING.encode(givenNamesValue)
		additionalNamesValue = value.additionalNames
		instance["additionalNames"] = serder.STRING.encode(additionalNamesValue)
		prefixesValue = value.prefixes
		instance["prefixes"] = serder.STRING.encode(prefixesValue)
		suffixesValue = value.suffixes
		instance["suffixes"] = serder.STRING.encode(suffixesValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IOrgUnits_VERSION = "3.1.28078"

class IOrgUnits(BaseEndpoint):
	def __init__(self, apiKey, url ,domain ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/directory/_ou/{domain}'
		self.domain_ = domain
		self.base = self.base.replace('{domain}',domain)

	def getAdministratorRoles (self, uid , dirUid ):
		postUri = "/{uid}/{dirUid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		postUri = postUri.replace("{dirUid}",dirUid);
		queryParams = {    };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def setAdministratorRoles (self, uid , dirUid , roles ):
		postUri = "/{uid}/{dirUid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		postUri = postUri.replace("{dirUid}",dirUid);
		__data__ = serder.SetSerDer(serder.STRING).encode(roles)

		queryParams = {     };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def update (self, uid , value ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.directory.api.OrgUnit import OrgUnit
		from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
		__data__ = __OrgUnitSerDer__().encode(value)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getAdministrators (self, uid ):
		postUri = "/{uid}/_administrators";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.OrgUnit import OrgUnit
		from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__OrgUnitSerDer__()), response)
	def search (self, query ):
		postUri = "/_search";
		__data__ = None
		from netbluemind.directory.api.OrgUnitQuery import OrgUnitQuery
		from netbluemind.directory.api.OrgUnitQuery import __OrgUnitQuerySerDer__
		__data__ = __OrgUnitQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
		from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
		return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)
	def getPath (self, uid ):
		postUri = "/{uid}/path";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
		from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
		return self.handleResult__(__OrgUnitPathSerDer__(), response)
	def create (self, uid , value ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.directory.api.OrgUnit import OrgUnit
		from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
		__data__ = __OrgUnitSerDer__().encode(value)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def listByAdministrator (self, administrator ):
		postUri = "/_byAdmin";
		__data__ = None
		queryParams = {  'administrator': administrator   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
		from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
		return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class PrintOptionsCalendarMetadata :
	def __init__( self):
		self.uid = None
		self.color = None
		pass

class __PrintOptionsCalendarMetadataSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = PrintOptionsCalendarMetadata()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		uidValue = value['uid']
		instance.uid = serder.STRING.parse(uidValue)
		colorValue = value['color']
		instance.color = serder.STRING.parse(colorValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		uidValue = value.uid
		instance["uid"] = serder.STRING.encode(uidValue)
		colorValue = value.color
		instance["color"] = serder.STRING.encode(colorValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
class ContainerDescriptor (BaseContainerDescriptor):
	def __init__( self):
		BaseContainerDescriptor.__init__(self)
		self.writable = None
		self.verbs = None
		self.offlineSync = None
		pass

class __ContainerDescriptorSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ContainerDescriptor()
		__BaseContainerDescriptorSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		writableValue = value['writable']
		instance.writable = serder.BOOLEAN.parse(writableValue)
		from netbluemind.core.container.model.acl.Verb import Verb
		from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
		verbsValue = value['verbs']
		instance.verbs = serder.SetSerDer(__VerbSerDer__()).parse(verbsValue)
		offlineSyncValue = value['offlineSync']
		instance.offlineSync = serder.BOOLEAN.parse(offlineSyncValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__BaseContainerDescriptorSerDer__().encodeInternal(value,instance)

		writableValue = value.writable
		instance["writable"] = serder.BOOLEAN.encode(writableValue)
		from netbluemind.core.container.model.acl.Verb import Verb
		from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
		verbsValue = value.verbs
		instance["verbs"] = serder.SetSerDer(__VerbSerDer__()).encode(verbsValue)
		offlineSyncValue = value.offlineSync
		instance["offlineSync"] = serder.BOOLEAN.encode(offlineSyncValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardOrganizationalMember :
	def __init__( self):
		self.commonName = None
		self.mailto = None
		self.containerUid = None
		self.itemUid = None
		pass

class __VCardOrganizationalMemberSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardOrganizationalMember()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		commonNameValue = value['commonName']
		instance.commonName = serder.STRING.parse(commonNameValue)
		mailtoValue = value['mailto']
		instance.mailto = serder.STRING.parse(mailtoValue)
		containerUidValue = value['containerUid']
		instance.containerUid = serder.STRING.parse(containerUidValue)
		itemUidValue = value['itemUid']
		instance.itemUid = serder.STRING.parse(itemUidValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		commonNameValue = value.commonName
		instance["commonName"] = serder.STRING.encode(commonNameValue)
		mailtoValue = value.mailto
		instance["mailto"] = serder.STRING.encode(mailtoValue)
		containerUidValue = value.containerUid
		instance["containerUid"] = serder.STRING.encode(containerUidValue)
		itemUidValue = value.itemUid
		instance["itemUid"] = serder.STRING.encode(itemUidValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VEventAttendeeQuery :
	def __init__( self):
		self.dir = None
		self.calendarOwnerAsDir = None
		self.partStatus = None
		pass

class __VEventAttendeeQuerySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VEventAttendeeQuery()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		dirValue = value['dir']
		instance.dir = serder.STRING.parse(dirValue)
		calendarOwnerAsDirValue = value['calendarOwnerAsDir']
		instance.calendarOwnerAsDir = serder.BOOLEAN.parse(calendarOwnerAsDirValue)
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
		partStatusValue = value['partStatus']
		instance.partStatus = __ICalendarElementParticipationStatusSerDer__().parse(partStatusValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		dirValue = value.dir
		instance["dir"] = serder.STRING.encode(dirValue)
		calendarOwnerAsDirValue = value.calendarOwnerAsDir
		instance["calendarOwnerAsDir"] = serder.BOOLEAN.encode(calendarOwnerAsDirValue)
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
		partStatusValue = value.partStatus
		instance["partStatus"] = __ICalendarElementParticipationStatusSerDer__().encode(partStatusValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class OrgUnitQuery :
	def __init__( self):
		self.from_ = None
		self.size = None
		self.query = None
		self.managableKinds = None
		pass

class __OrgUnitQuerySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = OrgUnitQuery()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from_Value = value['from']
		instance.from_ = serder.INT.parse(from_Value)
		sizeValue = value['size']
		instance.size = serder.INT.parse(sizeValue)
		queryValue = value['query']
		instance.query = serder.STRING.parse(queryValue)
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		managableKindsValue = value['managableKinds']
		instance.managableKinds = serder.SetSerDer(__DirEntryKindSerDer__()).parse(managableKindsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from_Value = value.from_
		instance["from"] = serder.INT.encode(from_Value)
		sizeValue = value.size
		instance["size"] = serder.INT.encode(sizeValue)
		queryValue = value.query
		instance["query"] = serder.STRING.encode(queryValue)
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		managableKindsValue = value.managableKinds
		instance["managableKinds"] = serder.SetSerDer(__DirEntryKindSerDer__()).encode(managableKindsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardParameter :
	def __init__( self):
		self.label = None
		self.value = None
		pass

class __VCardParameterSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardParameter()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		labelValue = value['label']
		instance.label = serder.STRING.parse(labelValue)
		valueValue = value['value']
		instance.value = serder.STRING.parse(valueValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		labelValue = value.label
		instance["label"] = serder.STRING.encode(labelValue)
		valueValue = value.value
		instance["value"] = serder.STRING.encode(valueValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxFolderHierarchy_VERSION = "3.1.28078"

class IMailboxFolderHierarchy(BaseEndpoint):
	def __init__(self, apiKey, url ,mailboxUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/mailbox-folders/{mailboxUid}'
		self.mailboxUid_ = mailboxUid
		self.base = self.base.replace('{mailboxUid}',mailboxUid)

	def multipleGet (self, arg0 ):
		postUri = "/_mget";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(arg0)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__FolderSerDer__())), response)
	def byUid (self, uid ):
		postUri = "/by_uid";
		__data__ = None
		queryParams = {  'uid': uid   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
	def allUids (self):
		postUri = "/_alluids";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def byParentId (self, parent ):
		postUri = "/by_parent_id";
		__data__ = None
		queryParams = {  'parent': parent   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__FolderSerDer__())), response)
	def changelog (self, arg0 ):
		postUri = "/_changelog";
		__data__ = None
		__data__ = serder.LONG.encode(arg0)

		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
		from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
		return self.handleResult__(__ContainerChangelogSerDer__(), response)
	def changeset (self, since ):
		postUri = "/_changeset";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
	def changesetById (self, since ):
		postUri = "/_changesetById";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
	def search (self, arg0 ):
		postUri = "/_search";
		__data__ = None
		from netbluemind.folder.api.FolderQuery import FolderQuery
		from netbluemind.folder.api.FolderQuery import __FolderQuerySerDer__
		__data__ = __FolderQuerySerDer__().encode(arg0)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		from netbluemind.core.api.ListResult import ListResult
		from netbluemind.core.api.ListResult import __ListResultSerDer__
		return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__FolderSerDer__())), response)
	def byPath (self, path ):
		postUri = "/_byPath";
		__data__ = None
		queryParams = {  'path': path   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
	def createUserMailFolder (self, imapPath ):
		postUri = "/_createUserMailFolder";
		__data__ = None
		queryParams = {  'imapPath': imapPath   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
	def reset (self):
		postUri = "/_reset";
		__data__ = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def byContentUri (self, uri ):
		postUri = "/by_uri";
		__data__ = None
		queryParams = {  'uri': uri   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
	def byId (self, id ):
		postUri = "/by_id";
		__data__ = None
		queryParams = {  'id': id   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum

class ErrorCode(Enum):
	UNKNOWN = 'UNKNOWN';
	PERMISSION_DENIED = 'PERMISSION_DENIED';
	FAILURE = 'FAILURE';
	INVALID_ID = 'INVALID_ID';
	INVALID_PARAMETER = 'INVALID_PARAMETER';
	AUTHENTICATION_FAIL = 'AUTHENTICATION_FAIL';
	SQL_ERROR = 'SQL_ERROR';
	NOT_FOUND = 'NOT_FOUND';
	ALREADY_EXISTS = 'ALREADY_EXISTS';
	FORBIDDEN = 'FORBIDDEN';
	ENTITY_TOO_LARGE = 'ENTITY_TOO_LARGE';
	INVALID_QUERY = 'INVALID_QUERY';
	INVALID_XML_RECEIVED = 'INVALID_XML_RECEIVED';
	CHILD_GROUP_MUST_EXIST = 'CHILD_GROUP_MUST_EXIST';
	CANT_DELETE_MYSELF = 'CANT_DELETE_MYSELF';
	DELEGATION_RESTRICTION = 'DELEGATION_RESTRICTION';
	INVALID_PASSWORD = 'INVALID_PASSWORD';
	LOGIN_ALREADY_USED = 'LOGIN_ALREADY_USED';
	INVALID_LOGIN = 'INVALID_LOGIN';
	EMPTY_LASTNAME = 'EMPTY_LASTNAME';
	EMPTY_VACATION_MESSAGE = 'EMPTY_VACATION_MESSAGE';
	VACATION_WITHOUT_MAILBOX = 'VACATION_WITHOUT_MAILBOX';
	FORWARDING_WITHOUT_MAILBOX = 'FORWARDING_WITHOUT_MAILBOX';
	FORWARDING_INVALID_EMAIL = 'FORWARDING_INVALID_EMAIL';
	INVALID_MAIL_SERVER = 'INVALID_MAIL_SERVER';
	INVALID_GROUP_NAME = 'INVALID_GROUP_NAME';
	FORWARDING_TO_OWN_MAILBOX = 'FORWARDING_TO_OWN_MAILBOX';
	SAME_PARENT_AND_CHILD_GROUP = 'SAME_PARENT_AND_CHILD_GROUP';
	INCLUSION_GROUP_LOOP = 'INCLUSION_GROUP_LOOP';
	EMAIL_ALREADY_USED = 'EMAIL_ALREADY_USED';
	INVALID_EMAIL = 'INVALID_EMAIL';
	MAIL_QUOTA_OVER_DOMAIN_LIMIT = 'MAIL_QUOTA_OVER_DOMAIN_LIMIT';
	NOT_GLOBAL_ADMIN = 'NOT_GLOBAL_ADMIN';
	DOMAIN_NAME_ALREADY_USED = 'DOMAIN_NAME_ALREADY_USED';
	INVALID_MAILSHARE_NAME = 'INVALID_MAILSHARE_NAME';
	INVALID_RESOURCE_NAME = 'INVALID_RESOURCE_NAME';
	OLD_PASSWORD_WRONG = 'OLD_PASSWORD_WRONG';
	OLD_PASSWORD_SAME_AS_NEW = 'OLD_PASSWORD_SAME_AS_NEW';
	IP_ADDRESS_ALREADY_USED = 'IP_ADDRESS_ALREADY_USED';
	MBOX_RENAME_FAILED = 'MBOX_RENAME_FAILED';
	INVALID_HOST_NAME = 'INVALID_HOST_NAME';
	EMPTY_EVENT_TITLE = 'EMPTY_EVENT_TITLE';
	NO_DURATION_EVENT = 'NO_DURATION_EVENT';
	NO_EVENT_DATE = 'NO_EVENT_DATE';
	NO_EVENT_TYPE = 'NO_EVENT_TYPE';
	EVENT_PRIVACY_INVALID = 'EVENT_PRIVACY_INVALID';
	EVENT_ERROR = 'EVENT_ERROR';
	CALENDAR_AUTHORISATION_ERROR = 'CALENDAR_AUTHORISATION_ERROR';
	CONTACT_DOMAIN_FORBIDDEN = 'CONTACT_DOMAIN_FORBIDDEN';
	EVENT_ENDREPEAT_PRIOR_TO_EVENT_DATE = 'EVENT_ENDREPEAT_PRIOR_TO_EVENT_DATE';
	INVALID_DOMAIN_NAME = 'INVALID_DOMAIN_NAME';
	GROUP_NAME_ALREADY_USED = 'GROUP_NAME_ALREADY_USED';
	INVALID_VACATION_RANGE = 'INVALID_VACATION_RANGE';
	EMPTY_DLIST_LABEL = 'EMPTY_DLIST_LABEL';
	EMPTY_DLIST_FOLDER = 'EMPTY_DLIST_FOLDER';
	DLIST_LOOP = 'DLIST_LOOP';
	CANT_UPDATE_ACL_IMPLICIT_RIGHTS = 'CANT_UPDATE_ACL_IMPLICIT_RIGHTS';
	USER_SPLIT_REQUIRES_SPLIT_DOMAIN = 'USER_SPLIT_REQUIRES_SPLIT_DOMAIN';
	SLAVE_RELAY_REQUIRES_SPLIT_DOMAIN = 'SLAVE_RELAY_REQUIRES_SPLIT_DOMAIN';
	INVALID_USER_LDAP_FILTER = 'INVALID_USER_LDAP_FILTER';
	SEC_GROUP_RM = 'SEC_GROUP_RM';
	NOT_IN_GLOBAL_DOMAIN = 'NOT_IN_GLOBAL_DOMAIN';
	NO_BACKUP_SERVER_FOUND = 'NO_BACKUP_SERVER_FOUND';
	OPERATION_ALREADY_RUNNING = 'OPERATION_ALREADY_RUNNING';
	INVALID_AD_HOST_NAME = 'INVALID_AD_HOST_NAME';
	JOB_FINISHED = 'JOB_FINISHED';
	INVALID_LICENSE = 'INVALID_LICENSE';
	HSM_MISSING_POLICY = 'HSM_MISSING_POLICY';
	INCOMPATIBLE_SMTP_TAGS = 'INCOMPATIBLE_SMTP_TAGS';
	INVALID_MAILBOX_NAME = 'INVALID_MAILBOX_NAME';
	TAG_ALREADY_EXIST = 'TAG_ALREADY_EXIST';
	INVALID_LINKED_MAILSHARE = 'INVALID_LINKED_MAILSHARE';
	MAILSHARE_GROUP_LINKED = 'MAILSHARE_GROUP_LINKED';
	SERVER_NOT_FOUND = 'SERVER_NOT_FOUND';
	DEPRECATED = 'DEPRECATED';

class __ErrorCodeSerDer__:
	def __init__( self):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ErrorCode[value]
		return instance


	def encode(self, value):
		if(value == None):
			return None
		instance = value.value
		return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardOrganizational :
	def __init__( self):
		self.title = None
		self.role = None
		self.org = None
		self.member = None
		pass

class __VCardOrganizationalSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardOrganizational()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		titleValue = value['title']
		instance.title = serder.STRING.parse(titleValue)
		roleValue = value['role']
		instance.role = serder.STRING.parse(roleValue)
		from netbluemind.addressbook.api.VCardOrganizationalOrg import VCardOrganizationalOrg
		from netbluemind.addressbook.api.VCardOrganizationalOrg import __VCardOrganizationalOrgSerDer__
		orgValue = value['org']
		instance.org = __VCardOrganizationalOrgSerDer__().parse(orgValue)
		from netbluemind.addressbook.api.VCardOrganizationalMember import VCardOrganizationalMember
		from netbluemind.addressbook.api.VCardOrganizationalMember import __VCardOrganizationalMemberSerDer__
		memberValue = value['member']
		instance.member = serder.ListSerDer(__VCardOrganizationalMemberSerDer__()).parse(memberValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		titleValue = value.title
		instance["title"] = serder.STRING.encode(titleValue)
		roleValue = value.role
		instance["role"] = serder.STRING.encode(roleValue)
		from netbluemind.addressbook.api.VCardOrganizationalOrg import VCardOrganizationalOrg
		from netbluemind.addressbook.api.VCardOrganizationalOrg import __VCardOrganizationalOrgSerDer__
		orgValue = value.org
		instance["org"] = __VCardOrganizationalOrgSerDer__().encode(orgValue)
		from netbluemind.addressbook.api.VCardOrganizationalMember import VCardOrganizationalMember
		from netbluemind.addressbook.api.VCardOrganizationalMember import __VCardOrganizationalMemberSerDer__
		memberValue = value.member
		instance["member"] = serder.ListSerDer(__VCardOrganizationalMemberSerDer__()).encode(memberValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementRRule :
	def __init__( self):
		self.frequency = None
		self.count = None
		self.until = None
		self.interval = None
		self.bySecond = None
		self.byMinute = None
		self.byHour = None
		self.byDay = None
		self.byMonthDay = None
		self.byYearDay = None
		self.byWeekNo = None
		self.byMonth = None
		pass

class __ICalendarElementRRuleSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementRRule()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import ICalendarElementRRuleFrequency
		from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import __ICalendarElementRRuleFrequencySerDer__
		frequencyValue = value['frequency']
		instance.frequency = __ICalendarElementRRuleFrequencySerDer__().parse(frequencyValue)
		countValue = value['count']
		instance.count = serder.INT.parse(countValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		untilValue = value['until']
		instance.until = __BmDateTimeSerDer__().parse(untilValue)
		intervalValue = value['interval']
		instance.interval = serder.INT.parse(intervalValue)
		bySecondValue = value['bySecond']
		instance.bySecond = serder.ListSerDer(serder.INT).parse(bySecondValue)
		byMinuteValue = value['byMinute']
		instance.byMinute = serder.ListSerDer(serder.INT).parse(byMinuteValue)
		byHourValue = value['byHour']
		instance.byHour = serder.ListSerDer(serder.INT).parse(byHourValue)
		from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import ICalendarElementRRuleWeekDay
		from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import __ICalendarElementRRuleWeekDaySerDer__
		byDayValue = value['byDay']
		instance.byDay = serder.ListSerDer(__ICalendarElementRRuleWeekDaySerDer__()).parse(byDayValue)
		byMonthDayValue = value['byMonthDay']
		instance.byMonthDay = serder.ListSerDer(serder.INT).parse(byMonthDayValue)
		byYearDayValue = value['byYearDay']
		instance.byYearDay = serder.ListSerDer(serder.INT).parse(byYearDayValue)
		byWeekNoValue = value['byWeekNo']
		instance.byWeekNo = serder.ListSerDer(serder.INT).parse(byWeekNoValue)
		byMonthValue = value['byMonth']
		instance.byMonth = serder.ListSerDer(serder.INT).parse(byMonthValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import ICalendarElementRRuleFrequency
		from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import __ICalendarElementRRuleFrequencySerDer__
		frequencyValue = value.frequency
		instance["frequency"] = __ICalendarElementRRuleFrequencySerDer__().encode(frequencyValue)
		countValue = value.count
		instance["count"] = serder.INT.encode(countValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		untilValue = value.until
		instance["until"] = __BmDateTimeSerDer__().encode(untilValue)
		intervalValue = value.interval
		instance["interval"] = serder.INT.encode(intervalValue)
		bySecondValue = value.bySecond
		instance["bySecond"] = serder.ListSerDer(serder.INT).encode(bySecondValue)
		byMinuteValue = value.byMinute
		instance["byMinute"] = serder.ListSerDer(serder.INT).encode(byMinuteValue)
		byHourValue = value.byHour
		instance["byHour"] = serder.ListSerDer(serder.INT).encode(byHourValue)
		from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import ICalendarElementRRuleWeekDay
		from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import __ICalendarElementRRuleWeekDaySerDer__
		byDayValue = value.byDay
		instance["byDay"] = serder.ListSerDer(__ICalendarElementRRuleWeekDaySerDer__()).encode(byDayValue)
		byMonthDayValue = value.byMonthDay
		instance["byMonthDay"] = serder.ListSerDer(serder.INT).encode(byMonthDayValue)
		byYearDayValue = value.byYearDay
		instance["byYearDay"] = serder.ListSerDer(serder.INT).encode(byYearDayValue)
		byWeekNoValue = value.byWeekNo
		instance["byWeekNo"] = serder.ListSerDer(serder.INT).encode(byWeekNoValue)
		byMonthValue = value.byMonth
		instance["byMonth"] = serder.ListSerDer(serder.INT).encode(byMonthValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class BmDateTime :
	def __init__( self):
		self.iso8601 = None
		self.timezone = None
		self.precision = None
		pass

class __BmDateTimeSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = BmDateTime()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		iso8601Value = value['iso8601']
		instance.iso8601 = serder.STRING.parse(iso8601Value)
		timezoneValue = value['timezone']
		instance.timezone = serder.STRING.parse(timezoneValue)
		from netbluemind.core.api.date.BmDateTimePrecision import BmDateTimePrecision
		from netbluemind.core.api.date.BmDateTimePrecision import __BmDateTimePrecisionSerDer__
		precisionValue = value['precision']
		instance.precision = __BmDateTimePrecisionSerDer__().parse(precisionValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		iso8601Value = value.iso8601
		instance["iso8601"] = serder.STRING.encode(iso8601Value)
		timezoneValue = value.timezone
		instance["timezone"] = serder.STRING.encode(timezoneValue)
		from netbluemind.core.api.date.BmDateTimePrecision import BmDateTimePrecision
		from netbluemind.core.api.date.BmDateTimePrecision import __BmDateTimePrecisionSerDer__
		precisionValue = value.precision
		instance["precision"] = __BmDateTimePrecisionSerDer__().encode(precisionValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardInfo :
	def __init__( self):
		self.kind = None
		self.mail = None
		self.tel = None
		self.formatedName = None
		self.categories = None
		self.memberCount = None
		self.photo = None
		self.source = None
		pass

class __VCardInfoSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardInfo()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.addressbook.api.VCardKind import VCardKind
		from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
		kindValue = value['kind']
		instance.kind = __VCardKindSerDer__().parse(kindValue)
		mailValue = value['mail']
		instance.mail = serder.STRING.parse(mailValue)
		telValue = value['tel']
		instance.tel = serder.STRING.parse(telValue)
		formatedNameValue = value['formatedName']
		instance.formatedName = serder.STRING.parse(formatedNameValue)
		from netbluemind.tag.api.TagRef import TagRef
		from netbluemind.tag.api.TagRef import __TagRefSerDer__
		categoriesValue = value['categories']
		instance.categories = serder.ListSerDer(__TagRefSerDer__()).parse(categoriesValue)
		memberCountValue = value['memberCount']
		instance.memberCount = serder.INT.parse(memberCountValue)
		photoValue = value['photo']
		instance.photo = serder.BOOLEAN.parse(photoValue)
		sourceValue = value['source']
		instance.source = serder.STRING.parse(sourceValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.addressbook.api.VCardKind import VCardKind
		from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
		kindValue = value.kind
		instance["kind"] = __VCardKindSerDer__().encode(kindValue)
		mailValue = value.mail
		instance["mail"] = serder.STRING.encode(mailValue)
		telValue = value.tel
		instance["tel"] = serder.STRING.encode(telValue)
		formatedNameValue = value.formatedName
		instance["formatedName"] = serder.STRING.encode(formatedNameValue)
		from netbluemind.tag.api.TagRef import TagRef
		from netbluemind.tag.api.TagRef import __TagRefSerDer__
		categoriesValue = value.categories
		instance["categories"] = serder.ListSerDer(__TagRefSerDer__()).encode(categoriesValue)
		memberCountValue = value.memberCount
		instance["memberCount"] = serder.INT.encode(memberCountValue)
		photoValue = value.photo
		instance["photo"] = serder.BOOLEAN.encode(photoValue)
		sourceValue = value.source
		instance["source"] = serder.STRING.encode(sourceValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Job :
	def __init__( self):
		self.domainStatus = None
		self.domainPlanification = None
		self.id = None
		self.description = None
		self.kind = None
		self.sendReport = None
		self.recipients = None
		pass

class __JobSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Job()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.scheduledjob.api.JobDomainStatus import JobDomainStatus
		from netbluemind.scheduledjob.api.JobDomainStatus import __JobDomainStatusSerDer__
		domainStatusValue = value['domainStatus']
		instance.domainStatus = serder.ListSerDer(__JobDomainStatusSerDer__()).parse(domainStatusValue)
		from netbluemind.scheduledjob.api.JobPlanification import JobPlanification
		from netbluemind.scheduledjob.api.JobPlanification import __JobPlanificationSerDer__
		domainPlanificationValue = value['domainPlanification']
		instance.domainPlanification = serder.ListSerDer(__JobPlanificationSerDer__()).parse(domainPlanificationValue)
		idValue = value['id']
		instance.id = serder.STRING.parse(idValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		from netbluemind.scheduledjob.api.JobKind import JobKind
		from netbluemind.scheduledjob.api.JobKind import __JobKindSerDer__
		kindValue = value['kind']
		instance.kind = __JobKindSerDer__().parse(kindValue)
		sendReportValue = value['sendReport']
		instance.sendReport = serder.BOOLEAN.parse(sendReportValue)
		recipientsValue = value['recipients']
		instance.recipients = serder.STRING.parse(recipientsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.scheduledjob.api.JobDomainStatus import JobDomainStatus
		from netbluemind.scheduledjob.api.JobDomainStatus import __JobDomainStatusSerDer__
		domainStatusValue = value.domainStatus
		instance["domainStatus"] = serder.ListSerDer(__JobDomainStatusSerDer__()).encode(domainStatusValue)
		from netbluemind.scheduledjob.api.JobPlanification import JobPlanification
		from netbluemind.scheduledjob.api.JobPlanification import __JobPlanificationSerDer__
		domainPlanificationValue = value.domainPlanification
		instance["domainPlanification"] = serder.ListSerDer(__JobPlanificationSerDer__()).encode(domainPlanificationValue)
		idValue = value.id
		instance["id"] = serder.STRING.encode(idValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		from netbluemind.scheduledjob.api.JobKind import JobKind
		from netbluemind.scheduledjob.api.JobKind import __JobKindSerDer__
		kindValue = value.kind
		instance["kind"] = __JobKindSerDer__().encode(kindValue)
		sendReportValue = value.sendReport
		instance["sendReport"] = serder.BOOLEAN.encode(sendReportValue)
		recipientsValue = value.recipients
		instance["recipients"] = serder.STRING.encode(recipientsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
class ResourceDescriptor (DirBaseValue):
	def __init__( self):
		DirBaseValue.__init__(self)
		self.label = None
		self.typeIdentifier = None
		self.description = None
		self.reservationMode = None
		self.properties = None
		pass

class __ResourceDescriptorSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ResourceDescriptor()
		__DirBaseValueSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		labelValue = value['label']
		instance.label = serder.STRING.parse(labelValue)
		typeIdentifierValue = value['typeIdentifier']
		instance.typeIdentifier = serder.STRING.parse(typeIdentifierValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		from netbluemind.resource.api.ResourceReservationMode import ResourceReservationMode
		from netbluemind.resource.api.ResourceReservationMode import __ResourceReservationModeSerDer__
		reservationModeValue = value['reservationMode']
		instance.reservationMode = __ResourceReservationModeSerDer__().parse(reservationModeValue)
		from netbluemind.resource.api.ResourceDescriptorPropertyValue import ResourceDescriptorPropertyValue
		from netbluemind.resource.api.ResourceDescriptorPropertyValue import __ResourceDescriptorPropertyValueSerDer__
		propertiesValue = value['properties']
		instance.properties = serder.ListSerDer(__ResourceDescriptorPropertyValueSerDer__()).parse(propertiesValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__DirBaseValueSerDer__().encodeInternal(value,instance)

		labelValue = value.label
		instance["label"] = serder.STRING.encode(labelValue)
		typeIdentifierValue = value.typeIdentifier
		instance["typeIdentifier"] = serder.STRING.encode(typeIdentifierValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		from netbluemind.resource.api.ResourceReservationMode import ResourceReservationMode
		from netbluemind.resource.api.ResourceReservationMode import __ResourceReservationModeSerDer__
		reservationModeValue = value.reservationMode
		instance["reservationMode"] = __ResourceReservationModeSerDer__().encode(reservationModeValue)
		from netbluemind.resource.api.ResourceDescriptorPropertyValue import ResourceDescriptorPropertyValue
		from netbluemind.resource.api.ResourceDescriptorPropertyValue import __ResourceDescriptorPropertyValueSerDer__
		propertiesValue = value.properties
		instance["properties"] = serder.ListSerDer(__ResourceDescriptorPropertyValueSerDer__()).encode(propertiesValue)
		return instance

